/*
 * Log.h
 *
 * Copyright 2002, 2003 by Anthony Howe.  All rights reserved.
 */

#ifndef __com_snert_lib_io_Log_h__
#define __com_snert_lib_io_Log_h__	1

#include <stdarg.h>

#define LOG_RAW			0
#define LOG_FATAL		1
#define LOG_ERROR		2
#define LOG_WARN		3
#define LOG_INFO		4
#define LOG_DEBUG		5

extern int LogOpen(const char *fname);
extern void LogClose(void);

extern const char *LogGetProgramName(void);
extern void LogSetProgramName(const char *);
extern void LogSetLevel(int level);

/*
 * Write to log file.
 */
extern void LogDebug(const char *fmt, ...);
extern void LogInfo(const char *fmt, ...);
extern void LogWarn(const char *fmt, ...);
extern void Log(int level, const char *fmt, ...);
extern void LogV(int level, const char *fmt, va_list args);

/*
 * Write to log file and standard error.
 */
extern void LogError(const char *fmt, ...);
extern void LogStderr(int level, const char *fmt, ...);
extern void LogStderrV(int level, const char *fmt, va_list args);

/*
 * Write to log file and standard error, then exit.
 */
extern void LogFatal(const char *fmt, ...);

#if defined(__WIN32__) || defined(__CYGWIN__)

#define LOG_EMERG  		LOG_FATAL
#define LOG_ALERT  		LOG_FATAL
#define LOG_CRIT   		LOG_ERROR
#define LOG_ERR    		LOG_ERROR
#define LOG_WARNING		LOG_WARN
#define LOG_NOTICE 		LOG_WARN

extern void openlog(const char *ident, int option, int facility);

/*
extern void syslog(int level, const char *fmt, ...);
extern void vsyslog(int level, const char *fmt, void *args);
extern void closelog(void);
*/

#define syslog		Log
#define vsyslog		LogV
#define closelog	LogClose

#endif

#ifdef  __cplusplus
}
#endif

#endif /* __com_snert_lib_io_Log_h__ */
