/*
 * Text.h
 *
 * Copyright 2001, 2003 by Anthony Howe.  All rights reserved.
 */

#ifndef __com_snert_lib_util_Text_h__
#define __com_snert_lib_util_Text_h__	1

#ifndef __com_snert_lib_util_Vector_h__
#include <com/snert/lib/util/Vector.h>
#endif

#ifndef __com_snert_lib_util_Buf_h__
#include <com/snert/lib/util/Buf.h>
#endif

#ifndef BUFSIZ
#include <stdio.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#ifndef CompareFunctionType
#define CompareFunctionType	1
typedef int (*CompareFunction)(const void *, const void *);
#endif

extern char *TextDup(const char *);
extern long TextHash(long, const char *);
extern int TextIsEmpty(const char *);
extern int TextIsInteger(const char *, int);
extern int TextBackslash(char);
extern char *TextToken(const char *, const char **, const char *);
extern Vector TextSplit(const char *, const char *);
extern char *TextJoin(const char *, Vector);

extern Buf TextExpand(Buf s, long col);
extern char *TextHexEncode(Buf b);

extern long TextCopyN(char *target, char *source, long len);

/*
 * Comparision functions; return -ve, 0, +ve for <, ==, >.
 */
extern int TextSensitiveCompare(const void *xp, void const *yp);
extern int TextSensitiveCompareN(const void *xp, void const *yp, long len);
extern int TextInsensitiveCompare(const void *xp, void const *yp);
extern int TextInsensitiveCompareN(const void *xp, void const *yp, long len);

/*
 * Comparision functions; return 0 or 1 for != or ==
 */
extern int TextSensitiveStartsWith(const char *text, const char *prefix);
extern int TextInsensitiveStartsWith(const char *text, const char *prefix);
extern int TextSensitiveEndsWith(const char *text, const char *suffix);
extern int TextInsensitiveEndsWith(const char *text, const char *suffix);

/*
 * Line input routines.
 */
extern int TextInputLine(FILE *fp, char *line, int size);
extern int TextReadLine(int fd, char *line, int size);

/*
 * Search routines.
 */
extern int TextCountOccurences(char *str, char *sub);

/*
 * In-place alterations.
 */
extern void TextInvert(char *str, long offset, long length);
extern void TextToLower(char *str, long offset, long length);
extern void TextToUpper(char *str, long offset, long length);
extern void TextReverse(char *str, long offset, long length);

extern void boundOffsetLength(long slength, long *offset, long *length);


#ifdef  __cplusplus
}
#endif

#endif /* __com_snert_lib_util_Text_h__ */
