/*
 * Property.c
 *
 * Copyright 2003 by Anthony Howe.  All rights reserved.
 */

#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#if defined(__BORLANDC__)
#include <io.h>
#else
#include <unistd.h>
#endif

#include <com/snert/lib/util/HashTable.h>
#include <com/snert/lib/util/Text.h>
#include <com/snert/lib/util/Property.h>

#define LINE_SIZE		1000

Property
PropertyCreate(void)
{
	return HashTableCreate(HashString, TextSensitiveCompare);
}

void
PropertyDestroy(Property property)
{
	HashTableDestroy((HashTable) property);
}

void *
PropertyGet(Property property, void *key)
{
	return HashTableGet((HashTable) property, key);
}

int
PropertySet(Property property, void *key, void *value)
{
	return HashTableSet((HashTable) property, key, value);
}

long
PropertyCount(Property property)
{
	return HashTableCount((HashTable) property);
}

Vector
PropertyKeys(Property property)
{
	return HashTableKeys((HashTable) property);
}

Vector
PropertyValues(Property property)
{
	return HashTableValues((HashTable) property);
}

int
PropertyLoad(Property property, const char *filename)
{
	int fd;
	long len;
	char *line;
	Vector fields;

	if ((line = (char *) malloc(LINE_SIZE)) == (char *) 0)
		goto error0;

	if ((fd = open(filename, O_RDONLY)) < 0)
		goto error1;

	while (0 <= (len = TextReadLine(fd, line, LINE_SIZE))) {
		fields = TextSplit(line, " \t,;");
		if (fields == (Vector) 0)
			goto error2;


	}

	close(fd);
	free(line);

	return 1;
error2:
	close(fd);
error1:
	free(line);
error0:
	return 0;
}

int
PropertySave(Property property, const char *filename)
{
}

